summaryrefslogtreecommitdiff
path: root/src/VBox/VMM/VMMR3/PDMDevice.cpp
diff options
context:
space:
mode:
authorvboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2017-12-08 17:23:10 +0000
committervboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2017-12-08 17:23:10 +0000
commit9b45346f53c0d0ce95c050f3c61136348cec70d6 (patch)
tree1d3283e41fd950cf33006ad3d94c19d657093668 /src/VBox/VMM/VMMR3/PDMDevice.cpp
parent0648c8ddee2b76dbc7eda7a37ffdc75f6b8ea007 (diff)
downloadVirtualBox-svn-9b45346f53c0d0ce95c050f3c61136348cec70d6.tar.gz
Fixed typo: Occurance -> Occurrence.
git-svn-id: https://www.virtualbox.org/svn/vbox/trunk@70039 cfe28804-0f27-0410-a406-dd0f0b0b656f
Diffstat (limited to 'src/VBox/VMM/VMMR3/PDMDevice.cpp')
-rw-r--r--src/VBox/VMM/VMMR3/PDMDevice.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/VBox/VMM/VMMR3/PDMDevice.cpp b/src/VBox/VMM/VMMR3/PDMDevice.cpp
index 1fb38c6a519..d24a2f86d7f 100644
--- a/src/VBox/VMM/VMMR3/PDMDevice.cpp
+++ b/src/VBox/VMM/VMMR3/PDMDevice.cpp
@@ -985,23 +985,23 @@ VMMR3DECL(int) PDMR3DriverAttach(PUVM pUVM, const char *pszDevice, unsigned iIns
* @param iLun The Logical Unit in which to look for the driver.
* @param pszDriver The name of the driver which to detach. If NULL
* then the entire driver chain is detatched.
* @param iOccurance The occurrence of that driver in the chain. This is
* usually 0.
* @param fFlags Flags, combination of the PDMDEVATT_FLAGS_* \#defines.
* @thread EMT
*/
VMMR3DECL(int) PDMR3DriverDetach(PUVM pUVM, const char *pszDevice, unsigned iDevIns, unsigned iLun,
- const char *pszDriver, unsigned iOccurance, uint32_t fFlags)
+ const char *pszDriver, unsigned iOccurrence, uint32_t fFlags)
{
- LogFlow(("PDMR3DriverDetach: pszDevice=%p:{%s} iDevIns=%u iLun=%u pszDriver=%p:{%s} iOccurance=%u fFlags=%#x\n",
- pszDevice, pszDevice, iDevIns, iLun, pszDriver, pszDriver, iOccurance, fFlags));
+ LogFlow(("PDMR3DriverDetach: pszDevice=%p:{%s} iDevIns=%u iLun=%u pszDriver=%p:{%s} iOccurrence=%u fFlags=%#x\n",
+ pszDevice, pszDevice, iDevIns, iLun, pszDriver, pszDriver, iOccurrence, fFlags));
UVM_ASSERT_VALID_EXT_RETURN(pUVM, VERR_INVALID_VM_HANDLE);
PVM pVM = pUVM->pVM;
VM_ASSERT_VALID_EXT_RETURN(pVM, VERR_INVALID_VM_HANDLE);
VM_ASSERT_EMT(pVM);
AssertPtr(pszDevice);
AssertPtrNull(pszDriver);
- Assert(iOccurance == 0 || pszDriver);
+ Assert(iOccurrence == 0 || pszDriver);
Assert(!(fFlags & ~(PDM_TACH_FLAGS_NOT_HOT_PLUG)));
/*
@@ -1023,9 +1023,9 @@ VMMR3DECL(int) PDMR3DriverDetach(PUVM pUVM, const char *pszDevice, unsigned iDev
{
if (!strcmp(pDrvIns->pReg->szName, pszDriver))
{
- if (iOccurance == 0)
+ if (iOccurrence == 0)
break;
- iOccurance--;
+ iOccurrence--;
}
pDrvIns = pDrvIns->Internal.s.pDown;
}
@@ -1060,7 +1060,7 @@ VMMR3DECL(int) PDMR3DriverDetach(PUVM pUVM, const char *pszDevice, unsigned iDev
* @param pszDriver The name of the driver which to detach and replace.
* If NULL then the entire driver chain is to be
* reattached.
* @param iOccurance The occurrence of that driver in the chain. This is
* usually 0.
* @param fFlags Flags, combination of the PDMDEVATT_FLAGS_* \#defines.
* @param pCfg The configuration of the new driver chain that is
@@ -1075,10 +1075,10 @@ VMMR3DECL(int) PDMR3DriverDetach(PUVM pUVM, const char *pszDevice, unsigned iDev
* @thread Any thread. The EMTs will be involved at some point though.
*/
VMMR3DECL(int) PDMR3DriverReattach(PUVM pUVM, const char *pszDevice, unsigned iDevIns, unsigned iLun,
- const char *pszDriver, unsigned iOccurance, uint32_t fFlags,
+ const char *pszDriver, unsigned iOccurrence, uint32_t fFlags,
PCFGMNODE pCfg, PPPDMIBASE ppBase)
{
- NOREF(pUVM); NOREF(pszDevice); NOREF(iDevIns); NOREF(iLun); NOREF(pszDriver); NOREF(iOccurance);
+ NOREF(pUVM); NOREF(pszDevice); NOREF(iDevIns); NOREF(iLun); NOREF(pszDriver); NOREF(iOccurrence);
NOREF(fFlags); NOREF(pCfg); NOREF(ppBase);
return VERR_NOT_IMPLEMENTED;
}
@@ -985,23 +985,23 @@ VMMR3DECL(int) PDMR3DriverAttach(PUVM pUVM, const char *pszDevice, unsigned iIns
* @param pszDriver The name of the driver which to detach. If NULL
* then the entire driver chain is detatched.
- * @param iOccurance The occurrence of that driver in the chain. This is
+ * @param iOccurrence The occurrence of that driver in the chain. This is
* usually 0.
* @param fFlags Flags, combination of the PDMDEVATT_FLAGS_* \#defines.
@@ -1060,7 +1060,7 @@ VMMR3DECL(int) PDMR3DriverDetach(PUVM pUVM, const char *pszDevice, unsigned iDev
* If NULL then the entire driver chain is to be
* reattached.
- * @param iOccurance The occurrence of that driver in the chain. This is
+ * @param iOccurrence The occurrence of that driver in the chain. This is
* usually 0.
* @param fFlags Flags, combination of the PDMDEVATT_FLAGS_* \#defines.